@@ -19,6 +19,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+import gettext
+
+gettext.install("ibus-libpinyin")
 
 def get_version():
-    return "1.9.1"
+    return "1.12.1"
+
+def get_longname():
+    return _("Intelligent Pinyin")
+
+def support_cloud_input():
+    return True
